/*
 * Copyright (C) 1999 Renaud Deraison
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <arpa/inet.h> /* for inet_ntoa */
#include <stdio.h> /* for printf */

#include "hosts_gatherer.h"

void
hg_dump_hosts (struct hg_host * hosts)
{
  while (hosts && hosts->next)
    {
      printf ("\t[ %s ]\tT: %d\tA : %d\tN : %d\t(%s)\n", inet_ntoa (hosts->addr),
              hosts->tested, hosts->alive,
              hosts->cidr_netmask,
              hosts->hostname);
      hosts = hosts->next;
    }
}
